# Clistyle

### Python3 library for coloring command line interface.

## install:

    pip install clistyle

## usage:

```python

from clistyle import Color

c = Color()

print(c.YELLOW + "Test Colors" + c.RESET)
print(c.BLUE + "Test Colors" + c.RESET)
print(c.GREEN + "Test Colors" + c.RESET)
print(c.CYAN + "Test Colors" + c.RESET)
print(c.MAGENTA + "Test Colors" + c.RESET)
print(c.RED + "Test Colors" + c.RESET)

```
## Output:

![Captura de tela de 2023-10-07 09-08-52](https://github.com/JuanBindez/clistyle/assets/79322362/3b754dda-e673-4948-a8fc-3fac442d52a9)


